<template>
    <nav class="pc-sidebar">
        <div class="navbar-wrapper">
            <div class="m-header">
                <Link href="/backoffice/admin/dashboard" class="b-brand text-primary">
                    <img src="/images/logo.png" alt="logo" style="max-width: 60px; height: auto;" />
                </Link>
            </div>

            <div class="navbar-content">
                <ul class="pc-navbar">
                    <li class="pc-item pc-caption">
                        <i class="ti ti-menu-2"></i>
                    </li>

                    <li
                        v-for="(item, index) in NavLink"
                        :key="index"
                        :class="['pc-item', { 'pc-hasmenu': item.children, active: isActive(item) || isActiveParent(item), 'pc-trigger': expanded[index] }]"
                    >
                        <!-- Menu tanpa children -->
                        <Link
                            v-if="!item.children"
                            :href="item.link"
                            class="pc-link"
                        >
                            <span class="pc-micon"><i :class="item.iconClass"></i></span>
                            <span class="pc-mtext">{{ item.label }}</span>
                        </Link>

                        <!-- Menu dengan children -->
                        <div v-else class="pc-link" @click="toggle(index)">
                            <span class="pc-micon"><i :class="item.iconClass"></i></span>
                            <span class="pc-mtext">{{ item.label }}</span>
                            <span class="pc-arrow"><i class="ti ti-chevron-right"></i></span>
                        </div>

                        <!-- Submenu -->
                        <ul v-if="item.children" class="pc-submenu">
                            <li
                                v-for="(child, childIndex) in item.children"
                                :key="childIndex"
                                class="pc-item"
                            >
                                <Link :href="child.link" class="pc-link">
                                    {{ child.label }}
                                </Link>
                            </li>
                        </ul>
                    </li>
                </ul>
            </div>
        </div>
    </nav>
</template>

<script setup>
import { ref, reactive, onMounted } from 'vue';
import { Link, usePage } from '@inertiajs/vue3';

const NavLink = ref([
    {
        label: 'Dashboard',
        link: '/backoffice/admin/dashboard',
        iconClass: 'ti ti-home',
    },
    {
        label: 'Datamaster',
        iconClass: 'ti ti-database',
        children: [
            {
                label: 'Jurusan',
                link: '/backoffice/admin/major',
            },
            {
                label: 'Tahun Lulus',
                link: '/backoffice/admin/graduation-year',
            },
            {
                label: 'Mitra DU/DI',
                link: '/backoffice/admin/company',
            },
        ],
    },
    {
        label: 'Lowongan',
        iconClass: 'ti ti-briefcase',
        children: [
            {
                label: 'Manajemen Lowongan',
                link: '/backoffice/admin/vacancy',
            },
        ],
    },
    {
        label: 'Management Alumni',
        iconClass: 'ti ti-users',
        link: '/backoffice/admin/alumni',
    },
    {
        label: 'Logout',
        iconClass: 'ti ti-logout',
        link: '/backoffice/admin/logout',
    },
]);

const expanded = reactive({});

const toggle = (index) => {
    expanded[index] = !expanded[index];
    // Close other submenus
    Object.keys(expanded).forEach((key) => {
        if (key !== index.toString()) {
            expanded[key] = false;
        }
    });
};

const isActive = (item) => {
    return usePage().url === item.link;
};

const isActiveParent = (item) => {
    if (item.children) {
        return item.children.some((child) => usePage().url.startsWith(child.link));
    }
    return false;
};

onMounted(() => {
    NavLink.value.forEach((item, index) => {
        if (item.children && isActiveParent(item)) {
            expanded[index] = true;
        } else if (item.children && expanded[index] === undefined) {
            expanded[index] = false;
        }
    });
});
</script>
